"""
Polymarket APIs - Unified interface for Polymarket's various APIs.

This package provides a comprehensive interface to Polymarket's APIs including:
- CLOB (Central Limit Order Book) API for trading
- Gamma API for event and market information
- Data API for user information
- Web3 API for blockchain interactions
- WebSocket API for real-time data streams
- GraphQL API for flexible data queries
"""

__version__ = "0.3.1"
__author__ = "Razvan Gheorghe"
__email__ = "razvan@gheorghe.me"

from .clients import (
    AsyncPolymarketGraphQLClient,
    PolymarketClobClient,
    PolymarketDataClient,
    PolymarketGammaClient,
    PolymarketGraphQLClient,
    PolymarketWeb3Client,
    PolymarketWebsocketsClient,
)
from .types.clob_types import MarketOrderArgs, OrderArgs

__all__ = [
    "AsyncPolymarketGraphQLClient",
    "MarketOrderArgs",
    "OrderArgs",
    "PolymarketClobClient",
    "PolymarketDataClient",
    "PolymarketGammaClient",
    "PolymarketGraphQLClient",
    "PolymarketWeb3Client",
    "PolymarketWebsocketsClient",
    "__author__",
    "__email__",
    "__version__",
]



"""
Client modules for Polymarket APIs.

This module contains all the client classes for interacting with different
Polymarket APIs including CLOB, Data, Gamma, GraphQL, Web3, and WebSocket clients.
"""

from .clob_client import PolymarketClobClient
from .data_client import PolymarketDataClient
from .gamma_client import PolymarketGammaClient
from .graphql_client import AsyncPolymarketGraphQLClient, PolymarketGraphQLClient
from .web3_client import PolymarketWeb3Client
from .websockets_client import PolymarketWebsocketsClient

__all__ = [
    "AsyncPolymarketGraphQLClient",
    "PolymarketClobClient",
    "PolymarketDataClient",
    "PolymarketGammaClient",
    "PolymarketGraphQLClient",
    "PolymarketWeb3Client",
    "PolymarketWebsocketsClient",
]



class InvalidPriceError(Exception):
    pass


class InvalidTickSizeError(Exception):
    pass


class InvalidFeeRateError(Exception):
    pass


class LiquidityError(Exception):
    pass


class MissingOrderbookError(Exception):
    pass


class AuthenticationRequiredError(ValueError):
    """Raised when authentication credentials are required but not provided."""



"""
Type definitions for Polymarket APIs.

This module contains all the Pydantic models and type definitions used across
the Polymarket APIs.
"""

from .clob_types import (
    ApiCreds,
    AssetType,
    BidAsk,
    BookParams,
    ClobMarket,
    ContractConfig,
    CreateOrderOptions,
    DailyEarnedReward,
    MarketOrderArgs,
    MarketRewards,
    Midpoint,
    OpenOrder,
    OrderArgs,
    OrderBookSummary,
    OrderCancelResponse,
    OrderPostResponse,
    OrderType,
    PaginatedResponse,
    PartialCreateOrderOptions,
    PolygonTrade,
    PostOrdersArgs,
    Price,
    PriceHistory,
    RequestArgs,
    RewardMarket,
    RoundConfig,
    Spread,
    TickSize,
    Token,
    TokenBidAsk,
    TokenBidAskDict,
    TokenValue,
    TokenValueDict,
)
from .common import EmptyString, EthAddress, Keccak256, TimeseriesPoint
from .data_types import (
    Activity,
    Holder,
    HolderResponse,
    Position,
    Trade,
    User,
    UserMetric,
    UserRank,
    ValueResponse,
)
from .gamma_types import (
    ClobReward,
    Event,
    EventList,
    GammaMarket,
    Pagination,
    QueryEvent,
    QueryMarket,
    Series,
    Tag,
)
from .websockets_types import (
    ActivityOrderMatchEvent,
    ActivityTrade,
    ActivityTradeEvent,
    AggOrderBookSummary,
    Comment,
    CommentEvent,
    CryptoPriceSubscribe,
    CryptoPriceSubscribeEvent,
    CryptoPriceUpdate,
    CryptoPriceUpdateEvent,
    ErrorEvent,
    LastTradePrice,
    LastTradePriceEvent,
    LiveDataClobMarket,
    LiveDataLastTradePriceEvent,
    LiveDataOrderBookSummaryEvent,
    LiveDataOrderEvent,
    LiveDataPriceChangeEvent,
    LiveDataTickSizeChangeEvent,
    LiveDataTradeEvent,
    MarketStatusChangeEvent,
    OrderBookSummaryEvent,
    OrderEvent,
    PriceChange,
    PriceChangeEvent,
    PriceChanges,
    Quote,
    QuoteEvent,
    Reaction,
    ReactionEvent,
    Request,
    RequestEvent,
    TickSizeChange,
    TickSizeChangeEvent,
    TradeEvent,
)

__all__ = [
    "Activity",
    "ActivityOrderMatchEvent",
    "ActivityTrade",
    "ActivityTradeEvent",
    "AggOrderBookSummary",
    "ApiCreds",
    "AssetType",
    "BidAsk",
    "BookParams",
    "ClobMarket",
    "ClobReward",
    "Comment",
    "CommentEvent",
    "ContractConfig",
    "CreateOrderOptions",
    "CryptoPriceSubscribe",
    "CryptoPriceSubscribeEvent",
    "CryptoPriceUpdate",
    "CryptoPriceUpdateEvent",
    "DailyEarnedReward",
    "EmptyString",
    "ErrorEvent",
    "EthAddress",
    "Event",
    "EventList",
    "GammaMarket",
    "Holder",
    "HolderResponse",
    "Keccak256",
    "LastTradePrice",
    "LastTradePriceEvent",
    "LiveDataClobMarket",
    "LiveDataLastTradePriceEvent",
    "LiveDataOrderBookSummaryEvent",
    "LiveDataOrderEvent",
    "LiveDataPriceChangeEvent",
    "LiveDataTickSizeChangeEvent",
    "LiveDataTradeEvent",
    "MarketOrderArgs",
    "MarketRewards",
    "MarketStatusChangeEvent",
    "Midpoint",
    "OpenOrder",
    "OrderArgs",
    "OrderBookSummary",
    "OrderBookSummaryEvent",
    "OrderCancelResponse",
    "OrderEvent",
    "OrderPostResponse",
    "OrderType",
    "PaginatedResponse",
    "Pagination",
    "PartialCreateOrderOptions",
    "PolygonTrade",
    "Position",
    "PostOrdersArgs",
    "Price",
    "PriceChange",
    "PriceChangeEvent",
    "PriceChanges",
    "PriceHistory",
    "QueryEvent",
    "QueryMarket",
    "Quote",
    "QuoteEvent",
    "Reaction",
    "ReactionEvent",
    "Request",
    "RequestArgs",
    "RequestEvent",
    "RewardMarket",
    "RoundConfig",
    "Series",
    "Spread",
    "Tag",
    "TickSize",
    "TickSizeChange",
    "TickSizeChangeEvent",
    "TimeseriesPoint",
    "Token",
    "TokenBidAsk",
    "TokenBidAskDict",
    "TokenValue",
    "TokenValueDict",
    "Trade",
    "TradeEvent",
    "User",
    "UserMetric",
    "UserRank",
    "ValueResponse",
]
